rf1: Funtion: rf1 to read a csv file and display an excerpt

Description Usage

View source: R/readfile.R

Description

Funtion: rf1 to read a csv file and display an excerpt

Usage

1
rf1(infile)

qwangcode/gssg_qw documentation built on June 17, 2020, 12:34 a.m.